/**
 * @(#)main.c 2008/03/09
 *
 * ICE Team free software group
 *
 * This file is part of JIIT64 Java Ice Team Tracker 64
 * See README for copyright notice. 
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
 */

#include "parse.h"
#include "membuf.h"
#include <stdio.h>
#include <stdlib.h>

/**
 * This is a wrapper for the Magnus Lind's assembler written in C
 * This code will be compiled for MIPS architecture and then convert to
 * Java bytecode with NestedVM.
 * Inside the JITT64 code, it will be called this main passing an input source 
 * file and the output file name to the converted Main.class
 * In Netbeans the library NestedVM will be defined as containing Main.class 
 * and Runtime.jar of NestedVM.
 */
int main(int argc, char *argv[]) {
  if (argc<2) return -1;

  struct membuf source=STATIC_MEMBUF_INIT;
  struct membuf dest=STATIC_MEMBUF_INIT;
  membuf_free(&source);
  membuf_free(&dest);

  // open the file to assemble
  FILE * pFile;
  long lSize;
  long result;

  pFile = fopen (argv[1], "rb");
  if (pFile==NULL) return -1;

  // obtain file size:
  fseek (pFile , 0 , SEEK_END);
  lSize = ftell (pFile);
  rewind (pFile);

  // allocate memory to contain the whole file:
  source.buf = (char*) malloc (sizeof(char)*lSize);
  if (source.buf == NULL) return -1;

  // copy the file into the buffer:
  result = fread (source.buf,1,lSize,pFile);
  if (result != lSize) return -1;

  source.size=lSize;
  source.len=lSize;

  fclose (pFile);

  int res=assemble(&source, &dest);

  membuf_free(&source);

  pFile = fopen ( argv[2] , "wb" );
  fwrite (dest.buf , 1 , dest.len , pFile );
  fclose (pFile);
  membuf_free(&dest);

  return res;
}
